@@ -24,6 +24,19 @@ def test_xml():
     check_expected(concepts)
 
 
+def test_skos_fr():
+    testdir = Path(__file__).parent
+    source = Path(testdir, 'data/categories.skos')
+    parser = SKOSKnowledgeParser()
+    options = SKOSOptionsModel(rdf_format=RDFFormat.xml, lang='fr',
+                               concept_class="http://www.artemis.gouv.fr/skos#Category")
+    concepts = list(parser.parse(source, options.dict(), Bar('Processing')))
+    assert len(concepts) == 27
+    c0: Term = concepts[0]
+    assert c0.identifier == 'http://www.artemis.fr/cbd6ac32-a405-4100-9f7c-6b00a9fd2484/Marine%20marchande'
+    assert c0.preferredForm == 'Marine marchande'
+
+
 def test_zipped_xml():
     testdir = Path(__file__).parent
     source = Path(testdir, 'data/test.rdf.zip')
